
From: Michael Still <mikal@stillhq.com>

The patch squelches build errors in the kernel-doc make targets by adding
documentation to arguements previously not documented, and updating the
argument names where they have changed.



 arch/i386/kernel/mca.c       |    4 +++-
 drivers/block/ll_rw_blk.c    |    8 ++++----
 drivers/pci/pci.c            |    6 ++++--
 drivers/serial/8250.c        |    6 ++++--
 drivers/serial/serial_core.c |    4 ++--
 fs/devfs/base.c              |    5 +++--
 fs/inode.c                   |    8 ++++++--
 fs/locks.c                   |   10 ++++++----
 fs/super.c                   |   11 ++++++-----
 include/linux/list.h         |    2 +-
 include/linux/skbuff.h       |    2 ++
 kernel/kmod.c                |    3 ++-
 mm/slab.c                    |    4 ++--
 net/core/dev.c               |    2 ++
 sound/oss/via82cxxx_audio.c  |    1 +
 15 files changed, 48 insertions(+), 28 deletions(-)

diff -puN arch/i386/kernel/mca.c~kernel-doc-fixes arch/i386/kernel/mca.c
--- 25/arch/i386/kernel/mca.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/arch/i386/kernel/mca.c	2003-10-02 18:27:08.000000000 -0700
@@ -132,7 +132,9 @@ struct resource mca_standard_resources[]
 #define MCA_STANDARD_RESOURCES	(sizeof(mca_standard_resources)/sizeof(struct resource))
 
 /**
- *	mca_read_pos - read the POS registers into a memory buffer
+ *	mca_read_and_store_pos - read the POS registers into a memory buffer
+ *      @pos: a char pointer to 8 bytes, contains the POS register value on
+ *            successful return
  *
  *	Returns 1 if a card actually exists (i.e. the pos isn't
  *	all 0xff) or 0 otherwise
diff -puN drivers/block/ll_rw_blk.c~kernel-doc-fixes drivers/block/ll_rw_blk.c
--- 25/drivers/block/ll_rw_blk.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/drivers/block/ll_rw_blk.c	2003-10-02 19:03:10.000000000 -0700
@@ -119,7 +119,7 @@ static void set_queue_congested(request_
 
 /**
  * blk_get_backing_dev_info - get the address of a queue's backing_dev_info
- * @dev:	device
+ * @bdev:	device
  *
  * Locates the passed device's request queue and returns the address of its
  * backing_dev_info
@@ -414,8 +414,8 @@ void blk_queue_segment_boundary(request_
 
 /**
  * blk_queue_dma_alignment - set dma length and memory alignment
- * @q:  the request queue for the device
- * @dma_mask:  alignment mask
+ * @q:     the request queue for the device
+ * @mask:  alignment mask
  *
  * description:
  *    set required memory and length aligment for direct dma transactions.
@@ -1152,7 +1152,7 @@ void blk_stop_queue(request_queue_t *q)
 
 /**
  * blk_run_queue - run a single device queue
- * @q	The queue to run
+ * @q:	The queue to run
  */
 void blk_run_queue(struct request_queue *q)
 {
diff -puN drivers/pci/pci.c~kernel-doc-fixes drivers/pci/pci.c
--- 25/drivers/pci/pci.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/drivers/pci/pci.c	2003-10-02 18:27:08.000000000 -0700
@@ -126,11 +126,13 @@ pci_find_capability(struct pci_dev *dev,
 
 /**
  * pci_bus_find_capability - query for devices' capabilities 
- * @dev: PCI device to query
- * @cap: capability code
+ * @bus:   the PCI bus to query
+ * @devfn: PCI device to query
+ * @cap:   capability code
  *
  * Like pci_find_capability() but works for pci devices that do not have a
  * pci_dev structure set up yet. 
+ *
  * Returns the address of the requested capability structure within the
  * device's PCI configuration space or 0 in case the device does not
  * support it.
diff -puN drivers/serial/8250.c~kernel-doc-fixes drivers/serial/8250.c
--- 25/drivers/serial/8250.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/drivers/serial/8250.c	2003-10-02 18:27:08.000000000 -0700
@@ -2124,7 +2124,8 @@ void serial8250_get_irq_map(unsigned int
 
 /**
  *	serial8250_suspend_port - suspend one serial port
- *	@line: serial line number
+ *	@line:  serial line number
+ *      @level: the level of port suspension, as per uart_suspend_port
  *
  *	Suspend one serial port.
  */
@@ -2135,7 +2136,8 @@ void serial8250_suspend_port(int line)
 
 /**
  *	serial8250_resume_port - resume one serial port
- *	@line: serial line number
+ *	@line:  serial line number
+ *      @level: the level of port resumption, as per uart_resume_port
  *
  *	Resume one serial port.
  */
diff -puN drivers/serial/serial_core.c~kernel-doc-fixes drivers/serial/serial_core.c
--- 25/drivers/serial/serial_core.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/drivers/serial/serial_core.c	2003-10-02 18:27:08.000000000 -0700
@@ -263,9 +263,9 @@ static void uart_shutdown(struct uart_st
 
 /**
  *	uart_update_timeout - update per-port FIFO timeout.
- *	@port: uart_port structure describing the port.
+ *	@port:  uart_port structure describing the port
  *	@cflag: termios cflag value
- *	@quot: uart clock divisor quotient
+ *	@baud:  speed of the port
  *
  *	Set the port FIFO timeout value.  The @cflag value should
  *	reflect the actual hardware settings.
diff -puN fs/devfs/base.c~kernel-doc-fixes fs/devfs/base.c
--- 25/fs/devfs/base.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/fs/devfs/base.c	2003-10-02 18:27:08.000000000 -0700
@@ -973,8 +973,9 @@ static struct devfs_entry *_devfs_search
 
 /**
  *	_devfs_alloc_entry - Allocate a devfs entry.
- *	@name:  The name of the entry.
- *	@namelen:  The number of characters in @name.
+ *	@name:     the name of the entry
+ *	@namelen:  the number of characters in @name
+ *      @mode:     the mode for the entry
  *
  *  Allocate a devfs entry and returns a pointer to the entry on success, else
  *   %NULL.
diff -puN fs/inode.c~kernel-doc-fixes fs/inode.c
--- 25/fs/inode.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/fs/inode.c	2003-10-02 19:03:11.000000000 -0700
@@ -255,6 +255,9 @@ void clear_inode(struct inode *inode)
 EXPORT_SYMBOL(clear_inode);
 
 /*
+ * dispose_list - dispose of the contents of a local list
+ * @head: the head of the list to free
+ *
  * Dispose-list gets a local list with local inodes in it, so it doesn't
  * need to worry about list corruption and SMP locks.
  */
@@ -739,11 +742,11 @@ EXPORT_SYMBOL(igrab);
 /**
  * ifind - internal function, you want ilookup5() or iget5().
  * @sb:		super block of file system to search
- * @hashval:	hash value (usually inode number) to search for
+ * @head:       the head of the list to search
  * @test:	callback used for comparisons between inodes
  * @data:	opaque data pointer to pass to @test
  *
- * ifind() searches for the inode specified by @hashval and @data in the inode
+ * ifind() searches for the inode specified by @data in the inode
  * cache. This is a generalized version of ifind_fast() for file systems where
  * the inode number is not sufficient for unique identification of an inode.
  *
@@ -775,6 +778,7 @@ static inline struct inode *ifind(struct
 /**
  * ifind_fast - internal function, you want ilookup() or iget().
  * @sb:		super block of file system to search
+ * @head:       head of the list to search
  * @ino:	inode number to search for
  *
  * ifind_fast() searches for the inode @ino in the inode cache. This is for
diff -puN fs/locks.c~kernel-doc-fixes fs/locks.c
--- 25/fs/locks.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/fs/locks.c	2003-10-02 18:27:08.000000000 -0700
@@ -928,10 +928,10 @@ int locks_mandatory_locked(struct inode 
  * locks_mandatory_area - Check for a conflicting lock
  * @read_write: %FLOCK_VERIFY_WRITE for exclusive access, %FLOCK_VERIFY_READ
  *		for shared
- * @inode: the file to check
- * @file: how the file was opened (if it was)
- * @offset: start of area to check
- * @count: length of area to check
+ * @inode:      the file to check
+ * @filp:       how the file was opened (if it was)
+ * @offset:     start of area to check
+ * @count:      length of area to check
  *
  * Searches the inode's list of locks to find any POSIX locks which conflict.
  * This function is called from locks_verify_area() and
@@ -1119,6 +1119,7 @@ out:
 /**
  *	lease_get_mtime
  *	@inode: the inode
+ *      @time:  pointer to a timespec which will contain the last modified time
  *
  * This is to force NFS clients to flush their caches for files with
  * exclusive leases.  The justification is that if someone has an
@@ -1726,6 +1727,7 @@ posix_block_lock(struct file_lock *block
 
 /**
  *	posix_unblock_lock - stop waiting for a file lock
+ *      @filp:   how the file was opened
  *	@waiter: the lock which was waiting
  *
  *	lockd needs to block waiting for locks.
diff -puN fs/super.c~kernel-doc-fixes fs/super.c
--- 25/fs/super.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/fs/super.c	2003-10-02 18:27:09.000000000 -0700
@@ -138,8 +138,8 @@ void deactivate_super(struct super_block
 EXPORT_SYMBOL(deactivate_super);
 
 /**
- *	grab_super	- acquire an active reference
- *	@s	- reference we are trying to make active
+ *	grab_super - acquire an active reference
+ *	@s: reference we are trying to make active
  *
  *	Tries to acquire an active reference.  grab_super() is used when we
  * 	had just found a superblock in super_blocks or fs_type->fs_supers
@@ -368,8 +368,8 @@ restart:
 }
 
 /**
- *	get_super	-	get the superblock of a device
- *	@dev: device to get the superblock for
+ *	get_super - get the superblock of a device
+ *	@bdev: device to get the superblock for
  *	
  *	Scans the superblock list and finds the superblock of the file system
  *	mounted on the device given. %NULL is returned if no match is found.
@@ -461,10 +461,11 @@ static void mark_files_ro(struct super_b
 }
 
 /**
- *	do_remount_sb	-	asks filesystem to change mount options.
+ *	do_remount_sb - asks filesystem to change mount options.
  *	@sb:	superblock in question
  *	@flags:	numeric part of options
  *	@data:	the rest of options
+ *      @force: whether or not to force the change
  *
  *	Alters the mount options of a mounted file system.
  */
diff -puN include/linux/list.h~kernel-doc-fixes include/linux/list.h
--- 25/include/linux/list.h~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/include/linux/list.h	2003-10-02 19:03:14.000000000 -0700
@@ -449,7 +449,7 @@ static __inline__ void hlist_del(struct 
 
 /**
  * hlist_del_rcu - deletes entry from hash list without re-initialization
- * @entry: the element to delete from the hash list.
+ * @n: the element to delete from the hash list.
  *
  * Note: list_unhashed() on entry does not return true after this, 
  * the entry is in an undefined state. It is useful for RCU based
diff -puN include/linux/skbuff.h~kernel-doc-fixes include/linux/skbuff.h
--- 25/include/linux/skbuff.h~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/include/linux/skbuff.h	2003-10-02 18:27:09.000000000 -0700
@@ -152,6 +152,7 @@ struct skb_shared_info {
  *	@sk: Socket we are owned by
  *	@stamp: Time we arrived
  *	@dev: Device we arrived on/are leaving by
+ *      @real_dev: The real device we are using
  *	@h: Transport layer header
  *	@nh: Network layer header
  *	@mac: Link layer header
@@ -179,6 +180,7 @@ struct skb_shared_info {
  *	@nfct: Associated connection, if any
  *	@nf_debug: Netfilter debugging
  *	@nf_bridge: Saved data about a bridged frame - see br_netfilter.c
+ *      @private: Data which is private to the HIPPI implementation
  *	@tc_index: Traffic control index
  */
 
diff -puN kernel/kmod.c~kernel-doc-fixes kernel/kmod.c
--- 25/kernel/kmod.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/kernel/kmod.c	2003-10-02 18:27:09.000000000 -0700
@@ -47,7 +47,8 @@ char modprobe_path[256] = "/sbin/modprob
 
 /**
  * request_module - try to load a kernel module
- * @module_name: Name of module
+ * @fmt:     printf style format string for the name of the module
+ * @varargs: arguements as specified in the format string
  *
  * Load a module using the user mode module loader. The function returns
  * zero on success or a negative errno code on failure. Note that a
diff -puN mm/slab.c~kernel-doc-fixes mm/slab.c
--- 25/mm/slab.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/mm/slab.c	2003-10-02 19:03:11.000000000 -0700
@@ -2675,8 +2675,8 @@ struct seq_operations slabinfo_op = {
  * slabinfo_write - Tuning for the slab allocator
  * @file: unused
  * @buffer: user buffer
- * @count: data len
- * @data: unused
+ * @count: data length
+ * @ppos: unused
  */
 ssize_t slabinfo_write(struct file *file, const char __user *buffer,
 				size_t count, loff_t *ppos)
diff -puN net/core/dev.c~kernel-doc-fixes net/core/dev.c
--- 25/net/core/dev.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/net/core/dev.c	2003-10-02 18:27:09.000000000 -0700
@@ -919,6 +919,8 @@ int unregister_netdevice_notifier(struct
 
 /**
  *	call_netdevice_notifiers - call all network notifier blocks
+ *      @val: value passed unmodified to notifier function
+ *      @v:   pointer passed unmodified to notifier function
  *
  *	Call all network notifier blocks.  Parameters and return value
  *	are as for notifier_call_chain().
diff -puN sound/oss/via82cxxx_audio.c~kernel-doc-fixes sound/oss/via82cxxx_audio.c
--- 25/sound/oss/via82cxxx_audio.c~kernel-doc-fixes	2003-10-02 18:27:08.000000000 -0700
+++ 25-akpm/sound/oss/via82cxxx_audio.c	2003-10-02 18:27:09.000000000 -0700
@@ -1844,6 +1844,7 @@ static void via_ac97_cleanup (struct via
 
 /**
  *	via_intr_channel - handle an interrupt for a single channel
+ *      @card: unused
  *	@chan: handle interrupt for this channel
  *
  *	This is the "meat" of the interrupt handler,

_
